Publish An Add-on Project — collective.addons documentation

# Publish An Add-on Project

Once the project owner added an add-on release or a linked add-on release to her / his project and released it she / he could return back to the add-on project page and submit the project for publication.

The project owner could do this within the menubar on the left side. She / he had to click on the menu entry ‘Private’ and than click on the entry ‘Submit for publication’ in the opening drop down menu. The menu entry will change from ‘Private’ to ‘Pending’.

The project owner will get an email with an information about this change of the workflow change. A corresponding email will be send to the administrator or a configured email address for this task (configured inside the ‘Add-on Center’.

The project has been forwarded into the review queue of the ‘Add-on Center’. Once the administrator, site-admiministrator or a reviewer changed the workflow state again, e.g. published the project, the project owner will get a further email with this new state.